Skip to main content
aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authorJohn Arthorne2009-10-07 20:50:43 +0000
committerJohn Arthorne2009-10-07 20:50:43 +0000
commit2554612d9db9c22d04144f3a3a06404f0f0959eb (patch)
tree79b129674555df25ac1a1ff2804f0f3756720780 /bundles
parent1506ab832acfb36976f44e2d466668edfd43b7a3 (diff)
downloadrt.equinox.p2-2554612d9db9c22d04144f3a3a06404f0f0959eb.tar.gz
rt.equinox.p2-2554612d9db9c22d04144f3a3a06404f0f0959eb.tar.xz
rt.equinox.p2-2554612d9db9c22d04144f3a3a06404f0f0959eb.zip
changed exception type
Diffstat (limited to 'bundles')
-rw-r--r--bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/internal/p2/core/DefaultAgentProvider.java2
-rw-r--r--bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/p2/core/IProvisioningAgentProvider.java11
2 files changed, 10 insertions, 3 deletions
diff --git a/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/internal/p2/core/DefaultAgentProvider.java b/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/internal/p2/core/DefaultAgentProvider.java
index 0f7b9b64e..2fd5b8f92 100644
--- a/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/internal/p2/core/DefaultAgentProvider.java
+++ b/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/internal/p2/core/DefaultAgentProvider.java
@@ -25,7 +25,7 @@ public class DefaultAgentProvider implements IProvisioningAgentProvider {
this.context = aContext;
}
- public IProvisioningAgent createAgent(URI location) throws Exception {
+ public IProvisioningAgent createAgent(URI location) {
ProvisioningAgent result = new ProvisioningAgent();
result.setLocation(location);
result.setBundleContext(context);
diff --git a/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/p2/core/IProvisioningAgentProvider.java b/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/p2/core/IProvisioningAgentProvider.java
index 010f3bf29..b3067c00c 100644
--- a/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/p2/core/IProvisioningAgentProvider.java
+++ b/bundles/org.eclipse.equinox.p2.core/src/org/eclipse/equinox/p2/core/IProvisioningAgentProvider.java
@@ -11,6 +11,7 @@
package org.eclipse.equinox.p2.core;
import java.net.URI;
+import org.eclipse.equinox.internal.provisional.p2.core.ProvisionException;
/**
* A service that is used to create or obtain instances of an
@@ -18,6 +19,12 @@ import java.net.URI;
* @since 1.1
*/
public interface IProvisioningAgentProvider {
+
+ /**
+ * Service name constant for the agent provider service.
+ */
+ public static final String SERVICE_NAME = IProvisioningAgentProvider.class.getName();
+
/**
* Creates a provisioning agent who metadata is stored at the given location.
* If a <code>null</code> location is provided, the provisioning agent for the
@@ -28,10 +35,10 @@ public interface IProvisioningAgentProvider {
* @param location The location where the agent metadata is stored
* @return A provisioning agent, or <code>null</code> if a <code>null</code>
* parameter is provided an there is no currently running agent.
* @throws Exception If agent creation failed. Reasons include:
* <ul>
* <li>The location is not writeable.</li>
* </ul>
*/
- public IProvisioningAgent createAgent(URI location) throws Exception;
+ public IProvisioningAgent createAgent(URI location) throws ProvisionException;
}

Back to the top
@@ -28,10 +35,10 @@ public interface IProvisioningAgentProvider {
* @return A provisioning agent, or <code>null</code> if a <code>null</code>
* parameter is provided an there is no currently running agent.
- * @throws Exception If agent creation failed. Reasons include:
+ * @throws ProvisionException If agent creation failed. Reasons include:
* <ul>
* <li>The location is not writeable.</li>